# Michael Kelly
# Article: Gathering Performance Information while Executing Everyday Automated Tests
# www.InformIT.com

# WATIR: http://rubyforge.org/projects/wtr/    
# Source compatible with version:  1.0.1

# BookPool_Search
# Test Search functionality
# Version 3.0 - Script modified to record times
#	In this version of the script, we need to calculate the times for how long certain actions take and then write them to our log file.
# 	This can be done using the Time.now command.

   #includes
   require '../watir.rb'   # the controller

   #variables
   testSite = 'http://www.BookPool.com'
   beginTime = 0
   endTime = 0

   #create a new log file
   scriptLog = File.new("BookPool_Search.log", "w") 	# Note that this file will be overwriten every time the scrip executes...

   scriptLog.puts '## Beginning of test: BookPool_Search'
   scriptLog.puts '  '
 
   #open the IE browser
   $ie = IE.new
   
   scriptLog.puts 'Step 1: go to the BookPool site: www.BookPool.com'
   beginTime = Time.now
   $ie.goto(testSite)
   endTime = Time.now
   scriptLog.puts 'Time Log: Home Page '+ (endTime - beginTime).to_s
   scriptLog.puts '  Action: entered ' + testSite + ' in the address bar.'

   scriptLog.puts 'Step 2: enter "Ruby: in the search text field under Simple Search'
   $ie.textField(:name, "qs").set("Ruby") # qs is the name of the search field
   scriptLog.puts '  Action: entered Ruby in the search field'

   scriptLog.puts 'Step 3: submit the search form.'
   beginTime = Time.now
   $ie.form(:index, "1").submit  #submitting first form found in the page.
   endTime = Time.now
   scriptLog.puts 'Time Log: Time to execute search '+ (endTime - beginTime).to_s
   scriptLog.puts '  Action: submitted search.'
   
   scriptLog.puts 'Expected Result: '
   scriptLog.puts ' - 7 results should be shown.'
  
   #All 7 results for Ruby:
   scriptLog.puts 'Actual Result: Check that the "All 7 results for Ruby:" message actually appears on the page by using an assertion'
   a = $ie.pageContainsText("All 7 results for Ruby:") 
   if !a 
      scriptLog.puts "Test Failed! Could not find test string: All 7 results for Ruby:" 
   else
      scriptLog.puts "Test Passed. Found the test string: All 7 results for Ruby:. Actual Results match Expected Results."
   end
   
   scriptLog.puts 'Close the browser'
   $ie.close()
   scriptLog.puts '  Action: browser closed.'
   
   scriptLog.puts '  '
   scriptLog.puts '## End of test: BookPool_Search'

   #close the file
   scriptLog.close
   
# -end of BookPool_Search test

